##  Detailed Guides
Guides | Description
---|---
[Creating a Survey](https://help.sap.com/docs/leanix/ea/creating-survey?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create surveys, from defining the scope and designing questions to using advanced fields and templates. Learn how to make questions mandatory, add links and descriptions, and import/export surveys.") | Learn how to create surveys, from defining the scope and designing questions to using advanced fields and templates. Learn how to make questions mandatory, add links and descriptions, and import/export surveys.
[Sending Out the Surveys](https://help.sap.com/docs/leanix/ea/sending-out-surveys?locale=en-US&state=PRODUCTION&version=CLOUD "Preview how the survey looks to the recipient, define the survey recipients based on fact sheet subscription roles, and compose an email invite to distribute the survey.") | Preview how the survey looks to the recipient, define the survey recipients based on fact sheet subscription roles, and compose an email invite to distribute the survey.
[Responding to Surveys](https://help.sap.com/docs/leanix/ea/responding-to-surveys?locale=en-US&state=PRODUCTION&version=CLOUD "Responding to surveys is crucial for providing feedback on enterprise architecture. Access surveys via the collaboration tab, fact sheets, or dashboard. Learn how to fill them and provide your insights.") | Responding to surveys is crucial for providing feedback on enterprise architecture. Access surveys via the collaboration tab, fact sheets, or dashboard. Learn how to fill them and provide your insights.
[Managing Surveys and Viewing Results](https://help.sap.com/docs/leanix/ea/managing-surveys-and-viewing-results?locale=en-US&state=PRODUCTION&version=CLOUD "Manage all your surveys centrally in the Collaboration tab of your workspace. Easily filter, sort, and search surveys, view results, finish, rerun, restart, or delete survey runs.") | Manage all your surveys centrally in the Collaboration tab of your workspace. Easily filter, sort, and search surveys, view results, finish, rerun, restart, or delete survey runs.
[Extended Guide on Survey Features](https://help.sap.com/docs/leanix/ea/extended-guide-on-survey-features?locale=en-US&state=PRODUCTION&version=CLOUD "Grant non-admins survey creation rights, prevent unintended notifications with Safety Net activation, and learn how to use API for survey management") | Grant non-admins survey creation rights, prevent unintended notifications with Safety Net activation, and learn how to use API for survey management.
[Calculated Fields in Surveys](https://help.sap.com/docs/leanix/ea/calculated-fields-in-surveys?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to configure calculated fields in surveys using JavaScript for advanced analysis and manipulation of data collected from survey responses.") | Learn how to configure calculated fields in surveys using JavaScript for advanced analysis and manipulation of data collected from survey responses.


